Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2632)

Unified Diff: chrome/common/render_messages_internal.h

Issue 5612002: Blacklist bad GPU drivers: currenly we disable all gpu related features if th... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/render_messages_internal.h
===================================================================
--- chrome/common/render_messages_internal.h (revision 68066)
+++ chrome/common/render_messages_internal.h (working copy)
@@ -45,6 +45,7 @@
// Substitution map for l10n messages.
typedef std::map<std::string, std::string> SubstitutionMap;
+class GpuFeatureFlags;
class GPUInfo;
class SerializedScriptValue;
class SkBitmap;
@@ -642,9 +643,10 @@
// The browser sends this to a renderer process in response to a
// ViewHostMsg_EstablishGpuChannel message.
- IPC_MESSAGE_CONTROL2(ViewMsg_GpuChannelEstablished,
+ IPC_MESSAGE_CONTROL3(ViewMsg_GpuChannelEstablished,
IPC::ChannelHandle /* handle to channel */,
- GPUInfo /* stats about GPU process*/)
+ GPUInfo /* stats about GPU process*/,
+ GpuFeatureFlags /* flags to blacklist gpu features*/)
// Notifies the renderer of the appcache that has been selected for a
// a particular host. This is sent in reply to AppCacheMsg_SelectCache.

Powered by Google App Engine
This is Rietveld 408576698